@@ -7,11 +7,10 @@ from __future__ import absolute_import, division, print_function
 
 
 __metaclass__ = type
-
 from textwrap import dedent
+from unittest.mock import patch
 
 from ansible_collections.cisco.ios.plugins.modules import ios_interfaces
-from ansible_collections.cisco.ios.tests.unit.compat.mock import patch
 from ansible_collections.cisco.ios.tests.unit.modules.utils import set_module_args
 
 from .ios_module import TestIosModule
@@ -150,7 +149,10 @@ class TestIosInterfacesModule(TestIosModule):
         set_module_args(
             {
                 "config": [
-                    {"description": "Ansible UT interface 1", "name": "GigabitEthernet1"},
+                    {
+                        "description": "Ansible UT interface 1",
+                        "name": "GigabitEthernet1",
+                    },
                     {
                         "description": "Ansible UT interface 2",
                         "name": "GigabitEthernet0/1",
@@ -204,7 +206,10 @@ class TestIosInterfacesModule(TestIosModule):
         set_module_args(
             {
                 "config": [
-                    {"description": "Ansible UT interface 1", "name": "GigabitEthernet1"},
+                    {
+                        "description": "Ansible UT interface 1",
+                        "name": "GigabitEthernet1",
+                    },
                     {"name": "GigabitEthernet0/1", "speed": 1200, "mtu": 1800},
                     {
                         "name": "GigabitEthernet6",
@@ -267,7 +272,10 @@ class TestIosInterfacesModule(TestIosModule):
         set_module_args(
             {
                 "config": [
-                    {"description": "Ansible UT interface 1", "name": "GigabitEthernet1"},
+                    {
+                        "description": "Ansible UT interface 1",
+                        "name": "GigabitEthernet1",
+                    },
                     {
                         "description": "Ansible UT interface 2",
                         "name": "GigabitEthernet0/1",
@@ -570,14 +578,22 @@ class TestIosInterfacesModule(TestIosModule):
                 "mtu": 1500,
                 "enabled": True,
             },
-            {"name": "GigabitEthernet1", "description": "Ansible UT interface 1", "enabled": True},
+            {
+                "name": "GigabitEthernet1",
+                "description": "Ansible UT interface 1",
+                "enabled": True,
+            },
             {
                 "name": "GigabitEthernet3",
                 "description": "Ansible UT interface 3",
                 "enabled": False,
                 "duplex": "auto",
             },
-            {"name": "GigabitEthernet4", "description": "Ansible UT interface 4", "enabled": False},
+            {
+                "name": "GigabitEthernet4",
+                "description": "Ansible UT interface 4",
+                "enabled": False,
+            },
             {
                 "name": "GigabitEthernet5",
                 "description": "Ansible UT interface 5",
