@@ -23,6 +23,7 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 from textwrap import dedent
+from unittest.mock import patch
 
 # TBD: These imports / import checks are only needed as a workaround for
 # shippable, which fails this test due to import yaml & import ordereddict.
@@ -32,7 +33,6 @@ from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos impor
     nxosCmdRef_import_check,
 )
 from ansible_collections.cisco.nxos.plugins.modules import nxos_telemetry
-from ansible_collections.cisco.nxos.tests.unit.compat.mock import patch
 from ansible_collections.cisco.nxos.tests.unit.modules.utils import AnsibleFailJson
 
 from .nxos_module import TestNxosModule, load_fixture, set_module_args
@@ -183,7 +183,10 @@ class TestNxosTelemetryModule(TestNxosModule):
     def test_tms_global_idempotent_n9k(self):
         # Assumes feature telemetry is enabled
         # TMS global config is present.
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
             dict(
@@ -205,7 +208,10 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Assumes feature telemetry is enabled
         # TMS global config is present
         # Change certificate
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
             dict(
@@ -233,7 +239,10 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Assumes feature telemetry is enabled
         # TMS global config is present
         # Change interface
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
             dict(
@@ -262,7 +271,10 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Assumes feature telemetry is enabled
         # TMS global config is present
         # Change source_interface, vrf and cert
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
             dict(
@@ -314,14 +326,19 @@ class TestNxosTelemetryModule(TestNxosModule):
         with pytest.raises(AnsibleFailJson) as errinfo:
             self.execute_module()
         testdata = errinfo.value.args[0]
-        assert "Parameter <id> under <destination_groups> is required" in str(testdata["msg"])
+        assert "Parameter <id> under <destination_groups> is required" in str(
+            testdata["msg"],
+        )
         assert testdata["failed"]
 
     def test_tms_destgroup_input_validation_2(self):
         # Parameter 'destination' is not a dict.
         self.execute_show_command.return_value = None
         self.get_platform_shortname.return_value = "N9K"
-        args = build_args([{"id": "88", "destination": "192.168.1.1"}], "destination_groups")
+        args = build_args(
+            [{"id": "88", "destination": "192.168.1.1"}],
+            "destination_groups",
+        )
         set_module_args(args, ignore_provider_arg)
         with pytest.raises(AnsibleFailJson) as errinfo:
             self.execute_module()
@@ -343,7 +360,9 @@ class TestNxosTelemetryModule(TestNxosModule):
         with pytest.raises(AnsibleFailJson) as errinfo:
             self.execute_module()
         testdata = errinfo.value.args[0]
-        assert "Playbook entry contains unrecongnized parameters" in str(testdata["msg"])
+        assert "Playbook entry contains unrecongnized parameters" in str(
+            testdata["msg"],
+        )
         assert testdata["failed"]
 
     def test_tms_destgroup_merged_n9k(self):
@@ -460,7 +479,10 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Assumes feature telemetry is enabled
         # TMS destgroup config is not present.
         # Configure only identifier
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
             [
@@ -483,7 +505,10 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Assumes feature telemetry is enabled
         # TMS destgroup config is not present.
         # Configure only identifier
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args([{"id": "2"}], "destination_groups")
         set_module_args(args, ignore_provider_arg)
@@ -492,7 +517,10 @@ class TestNxosTelemetryModule(TestNxosModule):
     def test_tms_destgroup_merged_aggregate_idempotent_n9k(self):
         # Assumes feature telemetry is enabled
         # TMS destgroup config is present.
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
             [
@@ -523,7 +551,10 @@ class TestNxosTelemetryModule(TestNxosModule):
     def test_tms_destgroup_change_n9k(self):
         # TMS destgroup config is not present.
         # Change protocol and encoding for dest group 2
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
             [
@@ -562,7 +593,10 @@ class TestNxosTelemetryModule(TestNxosModule):
         # TMS destgroup config is not present.
         # Add destinations to destgroup 10
         # Add new destgroup 55 and 56
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
             [
@@ -705,7 +739,9 @@ class TestNxosTelemetryModule(TestNxosModule):
         with pytest.raises(AnsibleFailJson) as errinfo:
             self.execute_module()
         testdata = errinfo.value.args[0]
-        assert "Parameter <id> under <sensor_groups> is required" in str(testdata["msg"])
+        assert "Parameter <id> under <sensor_groups> is required" in str(
+            testdata["msg"],
+        )
         assert testdata["failed"]
 
     def test_tms_sensorgroup_input_validation_2(self):
@@ -730,7 +766,9 @@ class TestNxosTelemetryModule(TestNxosModule):
         with pytest.raises(AnsibleFailJson) as errinfo:
             self.execute_module()
         testdata = errinfo.value.args[0]
-        assert "Parameter <path> under <sensor_groups> requires <name> key" in str(testdata["msg"])
+        assert "Parameter <path> under <sensor_groups> requires <name> key" in str(
+            testdata["msg"],
+        )
         assert testdata["failed"]
 
     def test_tms_sensorgroup_resource_key_n9k(self):
@@ -857,7 +895,10 @@ class TestNxosTelemetryModule(TestNxosModule):
     def test_tms_sensorgroup_merged_idempotent_n9k(self):
         # Assumes feature telemetry is enabled
         # TMS sensorgroup config is not present.
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
             [
@@ -880,7 +921,10 @@ class TestNxosTelemetryModule(TestNxosModule):
     def test_tms_sensorgroup_quotes_merged_idempotent_n9k(self):
         # Assumes feature telemetry is enabled
         # TMS sensorgroup config is present with quotes in NX-API path.
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K_SGs.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K_SGs.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
             [
@@ -906,7 +950,10 @@ class TestNxosTelemetryModule(TestNxosModule):
 
     def test_tms_sensorgroup_vxlan_idempotent_n9k(self):
         # TMS sensorgroup config present.
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
             [{"id": "56", "data_source": "DME", "path": {"name": "vxlan"}}],
@@ -917,7 +964,10 @@ class TestNxosTelemetryModule(TestNxosModule):
 
     def test_tms_sensorgroup_idempotent_variable1_n9k(self):
         # TMS sensorgroup config is present with path key name.
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
             [
@@ -936,7 +986,10 @@ class TestNxosTelemetryModule(TestNxosModule):
 
     def test_tms_sensorgroup_idempotent_variable2_n9k(self):
         # TMS sensorgroup config is present with path key name and depth.
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
             [
@@ -953,7 +1006,10 @@ class TestNxosTelemetryModule(TestNxosModule):
 
     def test_tms_sensorgroup_idempotent_resource_key_n9k(self):
         # TMS sensorgroup config is present resource key only.
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args([{"id": "55"}], "sensor_groups")
         set_module_args(args, ignore_provider_arg)
@@ -1013,7 +1069,7 @@ class TestNxosTelemetryModule(TestNxosModule):
             ],
         )
 
-    def test_tms_sensorgroup_present_path_interface_n9k(self):
+    def test_tms_sensorgroup_present_path_interface_n9k_1(self):
         # TMS sensorgroup config is not present.
         # Path name 'resources' test
         self.execute_show_command.return_value = None
@@ -1080,7 +1136,10 @@ class TestNxosTelemetryModule(TestNxosModule):
 
     def test_tms_subscription_merged_idempotent_n9k(self):
         # TMS subscription config is not present.
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
             [
@@ -1104,7 +1163,10 @@ class TestNxosTelemetryModule(TestNxosModule):
     def test_tms_subscription_merged_change1_n9k(self):
         # TMS subscription config present.
         # Change sample interval for sensor group 2
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
             [
@@ -1135,7 +1197,10 @@ class TestNxosTelemetryModule(TestNxosModule):
     def test_tms_subscription_add_n9k(self):
         # TMS subscription config present.
         # Add new destination_group and sensor_group to subscription 5
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
             [
@@ -1322,7 +1387,10 @@ class TestNxosTelemetryModule(TestNxosModule):
 
     def test_telemetry_deleted_input_validation_n9k(self):
         # State is 'deleted' and 'config' key present.
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
             dict(
@@ -1342,14 +1410,19 @@ class TestNxosTelemetryModule(TestNxosModule):
         with pytest.raises(AnsibleFailJson) as errinfo:
             self.execute_module()
         testdata = errinfo.value.args[0]
-        assert "Remove config key from playbook when state is <deleted>" in str(testdata["msg"])
+        assert "Remove config key from playbook when state is <deleted>" in str(
+            testdata["msg"],
+        )
         assert testdata["failed"]
 
     def test_telemetry_deleted_n9k(self):
         # Assumes feature telemetry is enabled
         # TMS global config is present.
         # Make absent with all playbook keys provided
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(dict(state="deleted"), ignore_provider_arg)
         self.execute_module(changed=True, commands=["no telemetry"])
@@ -1366,7 +1439,10 @@ class TestNxosTelemetryModule(TestNxosModule):
     def test_tms_replaced1_n9k(self):
         # Assumes feature telemetry is enabled
         # Modify global config and remove everything else
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
             dict(
@@ -1409,7 +1485,10 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Modify destination-group 10, add 11 and 99, remove 2
         # Modify sensor-group 55, 56
         # remove all subscriptions
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
             {
@@ -1525,7 +1604,10 @@ class TestNxosTelemetryModule(TestNxosModule):
         # remove all other destination-groups
         # Modify sensor-group 55 and delete all others
         # Modify subscription 7, add 10 and delete all others
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
             {
@@ -1616,7 +1698,10 @@ class TestNxosTelemetryModule(TestNxosModule):
         # remove all other destination-groups
         # Modify sensor-group 55 and delete all others
         # Modify subscription 7, add 10 and delete all others
-        self.execute_show_command.return_value = load_fixture("nxos_telemetry", "N9K.cfg")
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
             {
