@@ -6,19 +6,13 @@ from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
 
-import json
 import os
 import textwrap
 
-import pytest
-
-from mock import MagicMock
-
 from ansible import constants as C
-from ansible.errors import AnsibleError
-from ansible.inventory.data import InventoryData
 from ansible.inventory.manager import InventoryManager
 from ansible.module_utils.common.text.converters import to_native
+from ansible.utils.unsafe_proxy import AnsibleUnsafe
 
 from ansible_collections.community.internal_test_tools.tests.unit.mock.path import mock_unfrackpath_noop
 from ansible_collections.community.internal_test_tools.tests.unit.mock.loader import DictDataLoader
@@ -27,8 +21,6 @@ from ansible_collections.community.internal_test_tools.tests.unit.utils.open_url
     OpenUrlProxy,
 )
 
-from ansible_collections.community.dns.plugins.inventory.hosttech_dns_records import InventoryModule
-
 
 HOSTTECH_WSDL_DEFAULT_ENTRIES = [
     (125, 42, 'A', '', '1.2.3.4', 3600, None, None),
@@ -97,6 +89,64 @@ HOSTTECH_JSON_DEFAULT_ENTRIES = [
     },
 ]
 
+HOSTTECH_JSON_DEFAULT_ENTRIES_UNSAFE = [
+    # (125, 42, 'A', '', '1.2.{3.4', 3600, None, None),
+    {
+        'id': 125,
+        'type': 'A',
+        'name': '',
+        'ipv4': '1.2.{3.4',
+        'ttl': 3600,
+        'comment': '',
+    },
+    # (126, 42, 'A', '*', '1.2.{3.5', 3600, None, None),
+    {
+        'id': 126,
+        'type': 'A',
+        'name': '*',
+        'ipv4': '1.2.{3.5',
+        'ttl': 3600,
+        'comment': '',
+    },
+    # (127, 42, 'AAAA', '', '2001:1:2::{3', 3600, None, None),
+    {
+        'id': 127,
+        'type': 'AAAA',
+        'name': '',
+        'ipv6': '2001:1:2::{3',
+        'ttl': 3600,
+        'comment': '',
+    },
+    # (128, 42, 'AAAA', '*', '2001:1:2::{4', 3600, None, None),
+    {
+        'id': 128,
+        'type': 'AAAA',
+        'name': 'foo',
+        'ipv6': '2001:1:2::{4',
+        'ttl': 3600,
+        'comment': '',
+    },
+    # (129, 42, 'MX', '', 'example.com', 3600, None, '10'),
+    {
+        'id': 129,
+        'type': 'MX',
+        'ownername': '',
+        'name': 'example.com',
+        'pref': 10,
+        'ttl': 3600,
+        'comment': '',
+    },
+    # (130, 42, 'CNAME', 'bar', 'example.org.', 10800, None, None),
+    {
+        'id': 130,
+        'type': 'CNAME',
+        'name': 'bar',
+        'cname': 'example.org.',
+        'ttl': 10800,
+        'comment': '',
+    },
+]
+
 
 HOSTTECH_JSON_ZONE_LIST_RESULT = {
     "data": [
@@ -127,6 +177,18 @@ HOSTTECH_JSON_ZONE_RECORDS_GET_RESULT = {
     "data": HOSTTECH_JSON_DEFAULT_ENTRIES,
 }
 
+HOSTTECH_JSON_ZONE_GET_RESULT_UNSAFE = {
+    "data": {
+        "id": 42,
+        "name": "example.com",
+        "email": "test@example.com",
+        "ttl": 10800,
+        "nameserver": "ns1.hosttech.ch",
+        "dnssec": False,
+        "records": HOSTTECH_JSON_DEFAULT_ENTRIES_UNSAFE,
+    }
+}
+
 
 original_exists = os.path.exists
 original_access = os.access
@@ -158,7 +220,7 @@ def test_inventory_file_simple(mocker):
     plugin: community.dns.hosttech_dns_records
     hosttech_token: foo
     zone_name: example.com
-    filters:
+    simple_filters:
       type: A
     """)}
 
@@ -175,7 +237,7 @@ def test_inventory_file_simple(mocker):
         .expect_header('authorization', 'Bearer foo')
         .expect_url('https://api.ns1.hosttech.eu/api/user/v1/zones/42')
         .return_header('Content-Type', 'application/json')
-        .result_json(HOSTTECH_JSON_ZONE_GET_RESULT),
+        .result_json(HOSTTECH_JSON_ZONE_GET_RESULT_UNSAFE),
     ])
     mocker.patch('ansible_collections.community.dns.plugins.module_utils.http.open_url', open_url)
     mocker.patch('ansible.inventory.manager.unfrackpath', mock_unfrackpath_noop)
@@ -192,8 +254,10 @@ def test_inventory_file_simple(mocker):
     assert 'bar.example.com' not in im._inventory.hosts
     assert im._inventory.get_host('example.com') in im._inventory.groups['ungrouped'].hosts
     assert im._inventory.get_host('*.example.com') in im._inventory.groups['ungrouped'].hosts
-    assert im._inventory.get_host('example.com').get_vars()['ansible_host'] == '1.2.3.4'
-    assert im._inventory.get_host('*.example.com').get_vars()['ansible_host'] == '1.2.3.5'
+    assert im._inventory.get_host('example.com').get_vars()['ansible_host'] == '1.2.{3.4'
+    assert im._inventory.get_host('*.example.com').get_vars()['ansible_host'] == '1.2.{3.5'
+    assert isinstance(im._inventory.get_host('example.com').get_vars()['ansible_host'], AnsibleUnsafe)
+    assert isinstance(im._inventory.get_host('*.example.com').get_vars()['ansible_host'], AnsibleUnsafe)
     assert len(im._inventory.groups['ungrouped'].hosts) == 2
     assert len(im._inventory.groups['all'].hosts) == 0
 
@@ -206,7 +270,7 @@ def test_inventory_file_collision(mocker):
     plugin: community.dns.hosttech_dns_records
     hosttech_token: "{{ 'foo' }}"
     zone_name: "{{ 'example' ~ '.com' }}"
-    filters:
+    simple_filters:
       type:
         - A
         - AAAA
