@@ -1,4 +1,4 @@
-# (c) 2020-2023, NetApp, Inc
+# (c) 2020-2024, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 ''' unit test template for ONTAP Ansible module '''
@@ -100,7 +100,8 @@ volume_info = {
         "state": "on"
     },
     "access_time_enabled": True,
-    "snapshot_directory_access_enabled": True
+    "snapshot_directory_access_enabled": True,
+    "snapshot_locking_enabled": True
 }
 
 volume_info_mount = copy.deepcopy(volume_info)
@@ -528,7 +529,6 @@ def test_rest_version_error_with_atime_update():
         'atime_update': False
     }
     error = create_module(volume_module, DEFAULT_VOLUME_ARGS, module_args, fail=True)['msg']
-    print('error', error)
     assert 'Minimum version of ONTAP for atime_update is (9, 8)' in error
 
 
@@ -540,7 +540,6 @@ def test_rest_version_error_with_snapdir_access():
         'snapdir_access': False
     }
     error = create_module(volume_module, DEFAULT_VOLUME_ARGS, module_args, fail=True)['msg']
-    print('error', error)
     assert 'Minimum version of ONTAP for snapdir_access is (9, 13, 1)' in error
 
 
@@ -552,7 +551,6 @@ def test_rest_version_error_with_snapshot_auto_delete():
         'snapshot_auto_delete': {'state': 'on'}
     }
     error = create_module(volume_module, DEFAULT_VOLUME_ARGS, module_args, fail=True)['msg']
-    print('error', error)
     assert 'Minimum version of ONTAP for snapshot_auto_delete is (9, 13, 1)' in error
 
 
@@ -564,10 +562,32 @@ def test_rest_version_error_with_vol_nearly_full_threshold_percent():
         'vol_nearly_full_threshold_percent': 96
     }
     error = create_module(volume_module, DEFAULT_VOLUME_ARGS, module_args, fail=True)['msg']
-    print('error', error)
     assert 'Minimum version of ONTAP for vol_nearly_full_threshold_percent is (9, 9)' in error
 
 
+def test_rest_version_error_with_snapshot_locking():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_8_0'])
+    ])
+    module_args = {
+        'snapshot_locking': False
+    }
+    error = create_module(volume_module, DEFAULT_VOLUME_ARGS, module_args, fail=True)['msg']
+    print('error', error)
+    assert 'Minimum version of ONTAP for snapshot_locking is (9, 12, 1)' in error
+
+
+def test_rest_version_error_with_activity_tracking():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_8_0'])
+    ])
+    module_args = {
+        'activity_tracking': 'on'
+    }
+    error = create_module(volume_module, DEFAULT_VOLUME_ARGS, module_args, fail=True)['msg']
+    assert 'Minimum version of ONTAP for activity_tracking is (9, 10, 1)' in error
+
+
 def test_rest_successfully_modify_attributes_atime_update():
     register_responses([
         ('GET', 'cluster', SRR['is_rest_9_8_0']),
